/*****************************************************************************
 * FrameLessButton.cpp: A frameless QPushButton
 *****************************************************************************
 * Copyright (C) 2008-2016 VideoLAN
 *
 * Authors: Hugo Beauzée-Luyssen <hugo@beauzee.fr>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

/*
 *  Taken from VLC's source code.
 */

#include "FramelessButton.h"

#include <QPainter>

FramelessButton::FramelessButton( QWidget *parent )
  : QPushButton( parent )
{
    setSizePolicy( QSizePolicy::Preferred, QSizePolicy::Preferred );
}

void
FramelessButton::paintEvent( QPaintEvent* )
{
    QPainter    painter( this );
    QPixmap     pix = icon().pixmap( size() );
    QPoint      pos( ( width() - pix.width() ) / 2, ( height() - pix.height() ) / 2 );
    painter.drawPixmap( QRect( pos.x(), pos.y(), pix.width(), pix.height() ), pix );
}

QSize
FramelessButton::sizeHint() const
{
    return iconSize();
}
